@@ -3,20 +3,20 @@ package App::Nopaste::Service::Rafb;
 use strict;
 use warnings;
 use base 'App::Nopaste::Service';
-use WWW::Rafb::Create;
+use WWW::Pastebin::RafbNet::Create;
 
 sub run {
     my $self = shift;
     my %args = @_;
 
-    my $paster = WWW::Rafb::Create->new;
+    my $paster = WWW::Pastebin::RafbNet::Create->new;
     my $ok = $paster->paste(
         $args{text},
         %args,
     );
 
     return (0, $paster->error) unless $ok;
-    return (1, $paster->uri);
+    return (1, $paster->paste_uri);
 }
 
 =head1 NAME
@@ -25,7 +25,7 @@ App::Nopaste::Service::Rafb - http://www.rafb.net/paste/
 
 =head1 SEE ALSO
 
-L<WWW::Rafb::Create>
+L<WWW::Pastebin::RafbNet::Create>
 
 =cut
 
